# Python SDK
nector.io is a loyalty and reward APIs platform, that allows businesses to reward deals, offers, wallet points to their customers for various actions.

## Dependency
Python 3

## Installation
- `pip install joinnector` 

## Doumentation
Please refer https://docs.nector.io/merchant-integration/custom-integration/python-sdk

## Pip upload
https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56
